==> libxc-4.0.3.tar.gz: libxc-4.0.3/src/xc_funcs_removed.h <==
/*
 Copyright (C) 2016 M. Oliveira

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
  
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Lesser General Public License for more details.
  
 You should have received a copy of the GNU Lesser General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


/* These are old names kept for compatibility */
#define XC_GGA_X_BGCP          38
#define XC_GGA_C_BGCP          39
#define XC_GGA_C_VPBE          83
#define XC_MGGA_C_CC06        229
#define XC_GGA_XC_LB          160
#define XC_GGA_K_ABSR1        506
#define XC_GGA_K_ABSR2        507
#define XC_HYB_GGA_XC_mPW1PW  418
#define XC_HYB_GGA_XC_mPW1K   405


/* These are functionals that were removed */
#define XC_GGA_XC_B97      167 /* Becke 97                                 */
#define XC_GGA_XC_B97_1    168 /* Becke 97-1                               */
#define XC_GGA_XC_B97_2    169 /* Becke 97-2                               */ 
#define XC_GGA_XC_B97_K    171 /* Boese-Martin for Kinetics                */
#define XC_GGA_XC_B97_3    172 /* Becke 97-3                               */
#define XC_GGA_XC_SB98_1a  176 /* Schmider-Becke 98 parameterization 1a    */
#define XC_GGA_XC_SB98_1b  177 /* Schmider-Becke 98 parameterization 1b    */
#define XC_GGA_XC_SB98_1c  178 /* Schmider-Becke 98 parameterization 1c    */
#define XC_GGA_XC_SB98_2a  179 /* Schmider-Becke 98 parameterization 2a    */
#define XC_GGA_XC_SB98_2b  180 /* Schmider-Becke 98 parameterization 2b    */
#define XC_GGA_XC_SB98_2c  181 /* Schmider-Becke 98 parameterization 2c    */ 
#define XC_MGGA_X_M05      214 /* Worker for M05 functional                */ 
#define XC_MGGA_X_M05_2X   215 /* Worker for M05-2X functional             */
#define XC_MGGA_X_M06_HF   216 /* Worker for M06-HF functional             */ 
#define XC_MGGA_X_M06      217 /* Worker for M06 functional                */ 
#define XC_MGGA_X_M06_2X   218 /* Worker for M06-2X functional             */
#define XC_MGGA_X_MN12_SX  228 /* Worker for MN12-SX functional            */ 
#define XC_GGA_XC_WB97     251 /* Chai and Head-Gordon                     */
#define XC_GGA_XC_WB97X    252 /* Chai and Head-Gordon                     */
#define XC_GGA_XC_WB97X_V  253 /* Mardirossian and Head-Gordon             */
#define XC_GGA_XC_WB97X_D  256 /* Chai and Head-Gordon                     */ 
#define XC_MGGA_X_M08_HX       219 /* Worker for M08-HX functional     */
#define XC_MGGA_X_M08_SO       220 /* Worker for M08-SO functional     */
#define XC_MGGA_X_M11          225 /* Worker for M11 functional        */
#define XC_HYB_MGGA_XC_M08_HX  460 /* M08-HX functional from Minnesota */
#define XC_HYB_MGGA_XC_M08_SO  461 /* M08-SO functional from Minnesota */
#define XC_HYB_MGGA_XC_M11     462 /* M11    functional from Minnesota */

==> libxc_4.3.4.orig.tar.gz: libxc-4.3.4/src/xc_funcs_removed.h <==
/*
 Copyright (C) 2016 M. Oliveira

 This Source Code Form is subject to the terms of the Mozilla Public
 License, v. 2.0. If a copy of the MPL was not distributed with this
 file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/


/* These are old names kept for compatibility */
#define XC_GGA_X_BGCP          38
#define XC_GGA_C_BGCP          39
#define XC_GGA_C_VPBE          83
#define XC_MGGA_C_CC06        229
#define XC_GGA_XC_LB          160
#define XC_GGA_K_ABSR1        506
#define XC_GGA_K_ABSR2        507
#define XC_HYB_GGA_XC_mPW1PW  418
#define XC_HYB_GGA_XC_mPW1K   405
#define XC_LDA_C_LP_A         547 /* the next 3 functionals should be XC, not C */
#define XC_LDA_C_LP_B         548
#define XC_MGGA_C_LP90        564

/* These are functionals that were removed */
#define XC_GGA_XC_B97      167 /* Becke 97                                 */
#define XC_GGA_XC_B97_1    168 /* Becke 97-1                               */
#define XC_GGA_XC_B97_2    169 /* Becke 97-2                               */ 
#define XC_GGA_XC_B97_K    171 /* Boese-Martin for Kinetics                */
#define XC_GGA_XC_B97_3    172 /* Becke 97-3                               */
#define XC_GGA_XC_SB98_1a  176 /* Schmider-Becke 98 parameterization 1a    */
#define XC_GGA_XC_SB98_1b  177 /* Schmider-Becke 98 parameterization 1b    */
#define XC_GGA_XC_SB98_1c  178 /* Schmider-Becke 98 parameterization 1c    */
#define XC_GGA_XC_SB98_2a  179 /* Schmider-Becke 98 parameterization 2a    */
#define XC_GGA_XC_SB98_2b  180 /* Schmider-Becke 98 parameterization 2b    */
#define XC_GGA_XC_SB98_2c  181 /* Schmider-Becke 98 parameterization 2c    */ 
#define XC_MGGA_X_M05      214 /* Worker for M05 functional                */ 
#define XC_MGGA_X_M05_2X   215 /* Worker for M05-2X functional             */
#define XC_MGGA_X_M06_HF   216 /* Worker for M06-HF functional             */ 
#define XC_MGGA_X_M06      217 /* Worker for M06 functional                */ 
#define XC_MGGA_X_M06_2X   218 /* Worker for M06-2X functional             */
#define XC_MGGA_X_MN12_SX  228 /* Worker for MN12-SX functional            */ 
#define XC_GGA_XC_WB97     251 /* Chai and Head-Gordon                     */
#define XC_GGA_XC_WB97X    252 /* Chai and Head-Gordon                     */
#define XC_GGA_XC_WB97X_V  253 /* Mardirossian and Head-Gordon             */
#define XC_GGA_XC_WB97X_D  256 /* Chai and Head-Gordon                     */ 
#define XC_MGGA_X_M08_HX       219 /* Worker for M08-HX functional     */
#define XC_MGGA_X_M08_SO       220 /* Worker for M08-SO functional     */
#define XC_MGGA_X_M11          225 /* Worker for M11 functional        */
#define XC_HYB_MGGA_XC_M08_HX  460 /* M08-HX functional from Minnesota */
#define XC_HYB_MGGA_XC_M08_SO  461 /* M08-SO functional from Minnesota */
#define XC_HYB_MGGA_XC_M11     462 /* M11    functional from Minnesota */
